@@ -19,6 +19,9 @@ typedef struct {
     float normal;
     float lock_alpha;
     float colorize;
+    float posterize;
+    float posterize_num;
+    float paint;
 } OperationDataDrawDab;
 
 typedef struct OperationQueue OperationQueue;
